@@ -40,6 +40,8 @@ typedef struct _GstAllocatorClass GstAllocatorClass;
 #define GST_ALLOCATOR_CAST(obj)            ((GstAllocator *)(obj))
 
 #define GST_TYPE_ALLOCATION_PARAMS (gst_allocation_params_get_type())
+
+GST_EXPORT
 GType gst_allocation_params_get_type(void);
 
 typedef struct _GstAllocationParams GstAllocationParams;
@@ -50,6 +52,7 @@ typedef struct _GstAllocationParams GstAllocationParams;
  * The default memory alignment in bytes - 1
  * an alignment of 7 would be the same as what malloc() guarantees.
  */
+
 GST_EXPORT gsize gst_memory_alignment;
 
 /**
@@ -148,28 +151,50 @@ struct _GstAllocatorClass {
   gpointer _gst_reserved[GST_PADDING];
 };
 
-GType gst_allocator_get_type(void);
+GST_EXPORT
+GType          gst_allocator_get_type (void);
 
 /* allocators */
+
+GST_EXPORT
 void           gst_allocator_register        (const gchar *name, GstAllocator *allocator);
+
+GST_EXPORT
 GstAllocator * gst_allocator_find            (const gchar *name);
+
+GST_EXPORT
 void           gst_allocator_set_default     (GstAllocator * allocator);
 
 /* allocation parameters */
+
+GST_EXPORT
 void           gst_allocation_params_init    (GstAllocationParams *params);
+
+GST_EXPORT
 GstAllocationParams *
                gst_allocation_params_copy    (const GstAllocationParams *params) G_GNUC_MALLOC;
+
+GST_EXPORT
 void           gst_allocation_params_free    (GstAllocationParams *params);
 
 /* allocating memory blocks */
+
+GST_EXPORT
 GstMemory *    gst_allocator_alloc           (GstAllocator * allocator, gsize size,
                                               GstAllocationParams *params);
+
+GST_EXPORT
 void           gst_allocator_free            (GstAllocator * allocator, GstMemory *memory);
 
+GST_EXPORT
 GstMemory *    gst_memory_new_wrapped  (GstMemoryFlags flags, gpointer data, gsize maxsize,
                                         gsize offset, gsize size, gpointer user_data,
                                         GDestroyNotify notify);
 
+#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstAllocationParams, gst_allocation_params_free)
+#endif
+
 G_END_DECLS
 
 #endif /* __GST_ALLOCATOR_H__ */
