@@ -27,6 +27,7 @@
 
 G_BEGIN_DECLS
 
+GST_EXPORT
 GQuark gst_parse_error_quark (void);
 /**
  * GST_PARSE_ERROR:
@@ -35,6 +36,8 @@ GQuark gst_parse_error_quark (void);
  */
 #define GST_PARSE_ERROR gst_parse_error_quark ()
 
+/* FIXME 2.0: rename to GstParseLaunchError, this is not only related to
+ *parsing */
 /**
  * GstParseError:
  * @GST_PARSE_ERROR_SYNTAX: A syntax error occurred.
@@ -44,6 +47,7 @@ GQuark gst_parse_error_quark (void);
  * @GST_PARSE_ERROR_COULD_NOT_SET_PROPERTY: There was an error setting a property
  * @GST_PARSE_ERROR_EMPTY_BIN: An empty bin was specified.
  * @GST_PARSE_ERROR_EMPTY: An empty description was specified
+ * @GST_PARSE_ERROR_DELAYED_LINK: A delayed link did not get resolved.
  *
  * The different parsing errors that can occur.
  */
@@ -55,7 +59,8 @@ typedef enum
   GST_PARSE_ERROR_LINK,
   GST_PARSE_ERROR_COULD_NOT_SET_PROPERTY,
   GST_PARSE_ERROR_EMPTY_BIN,
-  GST_PARSE_ERROR_EMPTY
+  GST_PARSE_ERROR_EMPTY,
+  GST_PARSE_ERROR_DELAYED_LINK
 } GstParseError;
 
 /**
@@ -66,6 +71,9 @@ typedef enum
  *      in some cases)
  * @GST_PARSE_FLAG_NO_SINGLE_ELEMENT_BINS: If a bin only has a single element,
  *     just return the element.
+ * @GST_PARSE_FLAG_PLACE_IN_BIN: If more than one toplevel element is described
+ *     by the pipeline description string, put them in a #GstBin instead of a
+ *     #GstPipeline. (Since 1.10)
  *
  * Parsing options.
  */
@@ -73,7 +81,8 @@ typedef enum
 {
   GST_PARSE_FLAG_NONE = 0,
   GST_PARSE_FLAG_FATAL_ERRORS = (1 << 0),
-  GST_PARSE_FLAG_NO_SINGLE_ELEMENT_BINS = (1 << 1)
+  GST_PARSE_FLAG_NO_SINGLE_ELEMENT_BINS = (1 << 1),
+  GST_PARSE_FLAG_PLACE_IN_BIN = (1 << 2)
 } GstParseFlags;
 
 #define GST_TYPE_PARSE_CONTEXT (gst_parse_context_get_type())
@@ -87,27 +96,36 @@ typedef struct _GstParseContext GstParseContext;
 
 /* create, process and free a parse context */
 
+GST_EXPORT
 GType             gst_parse_context_get_type (void);
+
+GST_EXPORT
 GstParseContext * gst_parse_context_new (void) G_GNUC_MALLOC;
 
+GST_EXPORT
 gchar          ** gst_parse_context_get_missing_elements (GstParseContext * context) G_GNUC_MALLOC;
 
+GST_EXPORT
 void              gst_parse_context_free (GstParseContext * context);
 
+GST_EXPORT
+GstParseContext * gst_parse_context_copy (const GstParseContext * context);
+
 
 /* parse functions */
 
+GST_EXPORT
 GstElement      * gst_parse_launch       (const gchar      * pipeline_description,
                                           GError          ** error) G_GNUC_MALLOC;
-
+GST_EXPORT
 GstElement      * gst_parse_launchv      (const gchar     ** argv,
                                           GError          ** error) G_GNUC_MALLOC;
-
+GST_EXPORT
 GstElement      * gst_parse_launch_full  (const gchar      * pipeline_description,
                                           GstParseContext  * context,
                                           GstParseFlags      flags,
                                           GError          ** error) G_GNUC_MALLOC;
-
+GST_EXPORT
 GstElement      * gst_parse_launchv_full (const gchar     ** argv,
                                           GstParseContext  * context,
                                           GstParseFlags      flags,
