@@ -47,19 +47,32 @@ GST_EXPORT GType _gst_sample_type;
  */
 typedef struct _GstSample GstSample;
 
-GType gst_sample_get_type            (void);
+GST_EXPORT
+GType                gst_sample_get_type      (void);
 
 /* allocation */
+
+GST_EXPORT
 GstSample *          gst_sample_new           (GstBuffer          *buffer,
                                                GstCaps            *caps,
                                                const GstSegment   *segment,
                                                GstStructure       *info);
-
+GST_EXPORT
 GstBuffer *          gst_sample_get_buffer    (GstSample *sample);
+
+GST_EXPORT
 GstCaps *            gst_sample_get_caps      (GstSample *sample);
+
+GST_EXPORT
 GstSegment *         gst_sample_get_segment   (GstSample *sample);
+
+GST_EXPORT
 const GstStructure * gst_sample_get_info      (GstSample *sample);
+
+GST_EXPORT
 GstBufferList *      gst_sample_get_buffer_list (GstSample *sample);
+
+GST_EXPORT
 void                 gst_sample_set_buffer_list (GstSample *sample, GstBufferList *buffer_list);
 
 /* refcounting */
@@ -71,10 +84,6 @@ void                 gst_sample_set_buffer_list (GstSample *sample, GstBufferLis
  *
  * Returns: (transfer full): @sample
  */
-#ifdef _FOOL_GTK_DOC_
-G_INLINE_FUNC GstSample * gst_sample_ref (GstSample * sample);
-#endif
-
 static inline GstSample *
 gst_sample_ref (GstSample * sample)
 {
@@ -89,10 +98,6 @@ gst_sample_ref (GstSample * sample)
  * Decreases the refcount of the sample. If the refcount reaches 0, the
  * sample will be freed.
  */
-#ifdef _FOOL_GTK_DOC_
-G_INLINE_FUNC void gst_sample_unref (GstSample * sample);
-#endif
-
 static inline void
 gst_sample_unref (GstSample * sample)
 {
@@ -111,10 +116,6 @@ gst_sample_unref (GstSample * sample)
  *
  * Since: 1.2
  */
-#ifdef _FOOL_GTK_DOC_
-G_INLINE_FUNC GstSample * gst_sample_copy (const GstSample * buf);
-#endif
-
 static inline GstSample *
 gst_sample_copy (const GstSample * buf)
 {
@@ -149,6 +150,10 @@ gst_sample_copy (const GstSample * buf)
  */
 #define         gst_value_get_sample(v)         GST_SAMPLE_CAST (g_value_get_boxed(v))
 
+#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstSample, gst_sample_unref)
+#endif
+
 G_END_DECLS
 
 #endif /* __GST_SAMPLE_H__ */
