@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef __GST_BIT_READER_H__
@@ -50,29 +50,55 @@ typedef struct {
   gpointer _gst_reserved[GST_PADDING];
 } GstBitReader;
 
+GST_EXPORT
 GstBitReader *  gst_bit_reader_new              (const guint8 *data, guint size) G_GNUC_MALLOC;
+
+GST_EXPORT
 void            gst_bit_reader_free             (GstBitReader *reader);
 
+GST_EXPORT
 void            gst_bit_reader_init             (GstBitReader *reader, const guint8 *data, guint size);
 
+GST_EXPORT
 gboolean        gst_bit_reader_set_pos          (GstBitReader *reader, guint pos);
+
+GST_EXPORT
 guint           gst_bit_reader_get_pos          (const GstBitReader *reader);
 
+GST_EXPORT
 guint           gst_bit_reader_get_remaining    (const GstBitReader *reader);
 
+GST_EXPORT
 guint           gst_bit_reader_get_size         (const GstBitReader *reader);
 
+GST_EXPORT
 gboolean        gst_bit_reader_skip             (GstBitReader *reader, guint nbits);
+
+GST_EXPORT
 gboolean        gst_bit_reader_skip_to_byte     (GstBitReader *reader);
 
+GST_EXPORT
 gboolean        gst_bit_reader_get_bits_uint8   (GstBitReader *reader, guint8 *val, guint nbits);
+
+GST_EXPORT
 gboolean        gst_bit_reader_get_bits_uint16  (GstBitReader *reader, guint16 *val, guint nbits);
+
+GST_EXPORT
 gboolean        gst_bit_reader_get_bits_uint32  (GstBitReader *reader, guint32 *val, guint nbits);
+
+GST_EXPORT
 gboolean        gst_bit_reader_get_bits_uint64  (GstBitReader *reader, guint64 *val, guint nbits);
 
+GST_EXPORT
 gboolean        gst_bit_reader_peek_bits_uint8  (const GstBitReader *reader, guint8 *val, guint nbits);
+
+GST_EXPORT
 gboolean        gst_bit_reader_peek_bits_uint16 (const GstBitReader *reader, guint16 *val, guint nbits);
+
+GST_EXPORT
 gboolean        gst_bit_reader_peek_bits_uint32 (const GstBitReader *reader, guint32 *val, guint nbits);
+
+GST_EXPORT
 gboolean        gst_bit_reader_peek_bits_uint64 (const GstBitReader *reader, guint64 *val, guint nbits);
 
 /**
