@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef __GST_BUFFER_STRAW_H__
@@ -26,8 +26,13 @@
 
 G_BEGIN_DECLS
 
+GST_EXPORT
 void        gst_buffer_straw_start_pipeline (GstElement * bin, GstPad * pad);
+
+GST_EXPORT
 GstBuffer * gst_buffer_straw_get_buffer     (GstElement * bin, GstPad * pad);
+
+GST_EXPORT
 void        gst_buffer_straw_stop_pipeline  (GstElement * bin, GstPad * pad);
 
 G_END_DECLS
