@@ -90,7 +90,8 @@ struct _GstDirectControlBinding {
     struct {
       gboolean want_absolute;
     } abi;
-  } ABI;};
+  } ABI;
+};
 
 /**
  * GstDirectControlBindingClass:
@@ -108,16 +109,22 @@ struct _GstDirectControlBindingClass
   gpointer _gst_reserved[GST_PADDING];
 };
 
+GST_EXPORT
 GType gst_direct_control_binding_get_type (void);
 
 /* Functions */
 
+GST_EXPORT
 GstControlBinding * gst_direct_control_binding_new (GstObject * object, const gchar * property_name,
                                                     GstControlSource * cs);
-
+GST_EXPORT
 GstControlBinding * gst_direct_control_binding_new_absolute (GstObject * object, const gchar * property_name, 
                                                     GstControlSource * cs);
 
+#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstDirectControlBinding, gst_object_unref)
+#endif
+
 G_END_DECLS
 
 #endif /* __GST_DIRECT_CONTROL_BINDING_H__ */
