@@ -19,7 +19,7 @@
  * Boston, MA 02110-1301, USA.
  */
 /**
- * SECTION:gstlatency
+ * SECTION:element-latencytracer
  * @short_description: log processing latency stats
  *
  * A tracing module that determines src-to-sink latencies by injecting custom
@@ -106,7 +106,7 @@ log_latency (const GstStructure * data, GstPad * sink_pad, guint64 sink_ts)
   sink = g_strdup_printf ("%s_%s", GST_DEBUG_PAD_NAME (sink_pad));
 
   gst_tracer_record_log (tr_latency, src, sink,
-      GST_CLOCK_DIFF (src_ts, sink_ts));
+      GST_CLOCK_DIFF (src_ts, sink_ts), sink_ts);
   g_free (src);
   g_free (sink);
 }
@@ -125,23 +125,6 @@ send_latency_probe (GstElement * parent, GstPad * pad, guint64 ts)
   }
 }
 
-static void
-do_push_buffer_pre (GstTracer * self, guint64 ts, GstPad * pad)
-{
-  GstElement *parent = get_real_pad_parent (pad);
-
-  send_latency_probe (parent, pad, ts);
-}
-
-static void
-do_pull_range_pre (GstTracer * self, guint64 ts, GstPad * pad)
-{
-  GstPad *peer_pad = GST_PAD_PEER (pad);
-  GstElement *parent = get_real_pad_parent (peer_pad);
-
-  send_latency_probe (parent, peer_pad, ts);
-}
-
 static void
 calculate_latency (GstElement * parent, GstPad * pad, guint64 ts)
 {
@@ -158,12 +141,23 @@ calculate_latency (GstElement * parent, GstPad * pad, guint64 ts)
 }
 
 static void
-do_push_buffer_post (GstTracer * self, guint64 ts, GstPad * pad)
+do_push_buffer_pre (GstTracer * self, guint64 ts, GstPad * pad)
+{
+  GstPad *peer_pad = GST_PAD_PEER (pad);
+  GstElement *parent = get_real_pad_parent (pad);
+  GstElement *peer_parent = get_real_pad_parent (peer_pad);
+
+  send_latency_probe (parent, pad, ts);
+  calculate_latency (peer_parent, peer_pad, ts);
+}
+
+static void
+do_pull_range_pre (GstTracer * self, guint64 ts, GstPad * pad)
 {
   GstPad *peer_pad = GST_PAD_PEER (pad);
   GstElement *parent = get_real_pad_parent (peer_pad);
 
-  calculate_latency (parent, peer_pad, ts);
+  send_latency_probe (parent, peer_pad, ts);
 }
 
 static void
@@ -222,6 +216,12 @@ gst_latency_tracer_class_init (GstLatencyTracerClass * klass)
           "min", G_TYPE_UINT64, G_GUINT64_CONSTANT (0),
           "max", G_TYPE_UINT64, G_MAXUINT64,
           NULL),
+      "ts", GST_TYPE_STRUCTURE, gst_structure_new ("value",
+          "type", G_TYPE_GTYPE, G_TYPE_UINT64,
+          "description", G_TYPE_STRING, "ts when the latency has been logged",
+          "min", G_TYPE_UINT64, G_GUINT64_CONSTANT (0),
+          "max", G_TYPE_UINT64, G_MAXUINT64,
+          NULL),
       NULL);
   /* *INDENT-ON* */
 }
@@ -230,18 +230,24 @@ static void
 gst_latency_tracer_init (GstLatencyTracer * self)
 {
   GstTracer *tracer = GST_TRACER (self);
+
+  /* in push mode, pre/post will be called before/after the peer chain
+   * function has been called. For this reaosn, we only use -pre to avoid
+   * accounting for the processing time of the peer element (the sink) */
   gst_tracing_register_hook (tracer, "pad-push-pre",
       G_CALLBACK (do_push_buffer_pre));
   gst_tracing_register_hook (tracer, "pad-push-list-pre",
       G_CALLBACK (do_push_buffer_pre));
-  gst_tracing_register_hook (tracer, "pad-push-post",
-      G_CALLBACK (do_push_buffer_post));
-  gst_tracing_register_hook (tracer, "pad-push-list-post",
-      G_CALLBACK (do_push_buffer_post));
+
+  /* while in pull mode, pre/post will happend before and after the upstream
+   * pull_range call is made, so it already only account for the upstream
+   * processing time. As a side effect, in pull mode, we can measure the
+   * source processing latency, while in push mode, we can't */
   gst_tracing_register_hook (tracer, "pad-pull-range-pre",
       G_CALLBACK (do_pull_range_pre));
   gst_tracing_register_hook (tracer, "pad-pull-range-post",
       G_CALLBACK (do_pull_range_post));
+
   gst_tracing_register_hook (tracer, "pad-push-event-pre",
       G_CALLBACK (do_push_event_pre));
 }
